@@ -1,7 +1,8 @@
-################################################################################
 ##
 ## clusrank: Wilcoxon Rank Tests for Clustered Data
-## Copyright (C) 2015-2022  Yujing Jiang, Mei-Ling Ting Lee, and Jun Yan
+##
+## Copyright (C) 2015-2024 Yujing Jiang, Mei-Ling Ting Lee, and Jun Yan
+## Copyright (C) 2022-2024 Wenjie Wang
 ##
 ## This file is part of the R package clusrank.
 ##
@@ -15,48 +16,47 @@
 ## but WITHOUT ANY WARRANTY without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 ##
-################################################################################
 
 
-#' Identify clusters
-#'
-#' This is a special function used in the context of formula
-#' used for Wilcoxon sum rank test for clustered data.
-#' It identifies the cluster id of observations, and is used
-#' on the right hand side of a formula.
-#'
-#' @param x A numeric variable of cluster id.
-#'
-#' @details THe function's only action is semantic, to mark
-#' a variable as the cluster indicator. If not supplied,
-#' will assume no cluster in the data.
-#' @return x
-#' @seealso \code{\link{clusWilcox.test.formula}}
-#'
-#' @keywords internal
-#' @export
+##' Identify clusters
+##'
+##' This is a special function used in the context of formula
+##' used for Wilcoxon sum rank test for clustered data.
+##' It identifies the cluster id of observations, and is used
+##' on the right hand side of a formula.
+##'
+##' @param x A numeric variable of cluster id.
+##'
+##' @details THe function's only action is semantic, to mark
+##' a variable as the cluster indicator. If not supplied,
+##' will assume no cluster in the data.
+##' @return x
+##' @seealso \code{\link{clusWilcox.test.formula}}
+##'
+##' @keywords internal
+##' @export
 cluster <- function(x) {x}
 
-#' Identify strata.
-#'
-#' This is a special function used in the context of formula
-#' used for Wilcoxon sum rank test for clustered data.
-#' It identifies the stratum id of observations, and is used
-#' on the right hand side of a formula.
-#'
-#' @param x A numeric variable of stratum id.
-#'
-#' @details THe function's only action is semantic, to mark
-#' a variable as the stratum indicator. If not supplied,
-#' will assume no stratification in the data.
-#' @seealso clusWilcox.test.formula
-#'
-#' @keywords internal
-#' @export
+##' Identify strata.
+##'
+##' This is a special function used in the context of formula
+##' used for Wilcoxon sum rank test for clustered data.
+##' It identifies the stratum id of observations, and is used
+##' on the right hand side of a formula.
+##'
+##' @param x A numeric variable of stratum id.
+##'
+##' @details THe function's only action is semantic, to mark
+##' a variable as the stratum indicator. If not supplied,
+##' will assume no stratification in the data.
+##' @seealso clusWilcox.test.formula
+##'
+##' @keywords internal
+##' @export
 stratum <- function(x) {x}
 
 
-untangle.specials <- function (tt, special, order = 1)
+untangle_specials <- function (tt, special, order = 1)
 {
     spc <- attr(tt, "specials")[[special]]
     if (length(spc) == 0)
@@ -92,7 +92,7 @@ extractTerm <- function(term, mf, nobs, paired) {
         if (term == "group") {
             temp <- name <- term.mf
         } else {
-            temp <- untangle.specials(terms(mf), term, 1)
+            temp <- untangle_specials(terms(mf), term, 1)
             name <- gsub("[\\(\\)]", "",
                          regmatches(temp$vars,
                                     gregexpr("\\(.*?\\)", temp$vars))[[1]])
